#ifndef __MAIN_HEADER_INCLUDED__
#define __MAIN_HEADER_INCLUDED__
/* @(#) $Id: main.h,v 1.4 2002/02/25 14:42:54 gianni Exp $ */

enum {
	PHASE_CONNECT,
	PHASE_CONRESULT,
	PHASE_QUERY,
	PHASE_RECV,
	PHASE_WAIT
}phase;

#endif /* __MAIN_HEADER_INCLUDED__ */
